@@ -53,6 +53,10 @@ class MissingPermissionOnQuotaProjectError(c_creds.ADCError):
   """An error when ADC does not have permission to bill a quota project."""
 
 
+class AddQuotaProjectError(c_creds.ADCError):
+  """An error when quota project ID is added to creds that don't support it."""
+
+
 class _AcctInfo(object):
   """An auth command resource list item.
 
@@ -128,10 +132,18 @@ def PromptIfADCEnvVarIsSet():
 
 def WriteGcloudCredentialsToADC(creds, add_quota_project=False):
   """Writes gclouds's credential from auth login to ADC json."""
-  if not c_creds.IsUserAccountCredentials(creds):
+  # TODO(b/190114370): We will also support writing service account creds.
+  if (not c_creds.IsUserAccountCredentials(creds) and
+      not c_creds.IsExternalAccountCredentials(creds)):
     log.warning('Credentials cannot be written to application default '
-                'credentials because it is not a user credential.')
+                'credentials because it is not a user or external account '
+                'credential.')
     return
+  # Quota project ID should not be added to non-user credentials.
+  if c_creds.IsExternalAccountCredentials(creds) and add_quota_project:
+    raise AddQuotaProjectError(
+        'The application default credentials are external account credentials, '
+        'quota project cannot be added.')
 
   PromptIfADCEnvVarIsSet()
   if add_quota_project:
@@ -231,7 +243,8 @@ def DumpADC(credentials, quota_project_disabled=False):
   Args:
      credentials: a credentials from oauth2client or google-auth libraries, the
        credentials to dump.
-     quota_project_disabled: bool, If quota project is explicitly disabled.
+     quota_project_disabled: bool, If quota project is explicitly disabled by
+       users using flags.
   """
   adc_path = c_creds.ADC(credentials).DumpADCToFile()
   LogADCIsWritten(adc_path)
@@ -295,3 +308,10 @@ def AddQuotaProjectToADC(quota_project):
       quota_project=quota_project)
   LogADCIsWritten(adc_path)
   LogQuotaProjectAdded(quota_project)
+
+
+def DumpImpersonatedServiceAccountToADC(credentials, target_principal,
+                                        delegates):
+  adc_path = c_creds.ADC(credentials, target_principal,
+                         delegates).DumpADCToFile()
+  LogADCIsWritten(adc_path)
