@@ -23,7 +23,7 @@ from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions
 from googlecloudsdk.command_lib.secrets import args as secrets_args
 from googlecloudsdk.command_lib.secrets import fmt as secrets_fmt
-from googlecloudsdk.command_lib.secrets import util as secrets_util
+from googlecloudsdk.core.resource import resource_expr_rewrite
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
@@ -31,8 +31,8 @@ class List(base.ListCommand):
   r"""List all secret names.
 
   List all secret names. This command only returns the secret's names, not
-  their secret data. To retrieve the secret's data, run `$ {parent_command}
-  access SECRET`.
+  their secret data. To learn about retrieving a secret's data, run
+  `$ {parent_command} versions access --help`.
 
   ## EXAMPLES
 
@@ -44,7 +44,7 @@ class List(base.ListCommand):
   @staticmethod
   def Args(parser):
     secrets_args.AddProject(parser)
-    secrets_fmt.UseSecretTable(parser, 'v1')
+    secrets_fmt.UseSecretTable(parser)
     base.PAGE_SIZE_FLAG.SetDefault(parser, 100)
 
   def Run(self, args):
@@ -54,10 +54,8 @@ class List(base.ListCommand):
           'project',
           'Please set a project with "--project" flag or "gcloud config set project <project_id>".'
       )
-    return secrets_api.Secrets(
-        version=secrets_util.GetVersionFromReleasePath(
-            self.ReleaseTrack())).ListWithPager(
-                project_ref=project_ref, limit=args.limit)
+    return secrets_api.Secrets().ListWithPager(
+        project_ref=project_ref, limit=args.limit)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.BETA)
@@ -65,8 +63,8 @@ class ListBeta(List):
   r"""List all secret names.
 
   List all secret names. This command only returns the secret's names, not
-  their secret data. To retrieve the secret's data, run `$ {parent_command}
-  access SECRET`.
+  their secret data. To learn about retrieving a secret's data, run
+  `$ {parent_command} versions access --help`.
 
   ## EXAMPLES
 
@@ -78,5 +76,20 @@ class ListBeta(List):
   @staticmethod
   def Args(parser):
     secrets_args.AddProject(parser)
-    secrets_fmt.UseSecretTable(parser, 'v1beta1')
+    secrets_fmt.UseSecretTable(parser)
     base.PAGE_SIZE_FLAG.SetDefault(parser, 100)
+
+  def Run(self, args):
+    project_ref = args.CONCEPTS.project.Parse()
+    if not project_ref:
+      raise exceptions.RequiredArgumentException(
+          'project',
+          'Please set a project with "--project" flag or "gcloud config set project <project_id>".'
+      )
+    rewriter = resource_expr_rewrite.Backend()
+    server_filter = None
+    if args.filter:
+      _, server_filter = rewriter.Rewrite(args.filter)
+
+    return secrets_api.Secrets().ListWithPager(
+        project_ref=project_ref, limit=args.limit, request_filter=server_filter)
